@@ -31,4 +31,4 @@ With a variety of sources, target storage systems, etc.
 
 """
 
-from know.util import ContextFanout, FuncFanout, MultiIterable, any_value_is_none
+from know.util import ContextFanout, any_value_is_none, ContextualFunc
